@@ -54,8 +54,8 @@ features of the Lisz demo app
 lisz application data model
 ---------------------------
 
-The Lisz demo app is managing a recursive item tree that can be used e.g. as to-do or
-shopping list.
+The Lisz demo app is managing a recursive item tree - a list of lists - that can be used
+e.g. as a to-do or shopping list.
 
 To keep this demo app simple, the data managed by the Lisz application is a minimalistic
 tree structure that gets stored as an :ref:`application status`, without the need of any
@@ -99,7 +99,7 @@ GUI framework demo implementations
 The plan is to integrate the following GUI frameworks on
 top of the :class:`abstract base class <~ae.gui_app.MainAppBase>`
 (implemented in the :mod:`ae.gui_app` portion of the
-`ae namespace <https://ae.readthedocs.io`__):
+`ae namespace <https://ae.readthedocs.io>`__):
 
 * :mod:`Kivy <ae.kivy_app>` based on the `kivy framework <https://kivy.org>`__:
   `kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>`__
@@ -131,6 +131,50 @@ on the `kivy framework <https://kivy.org>`__,
 a `pypi package <https://pypi.org/project/Kivy/>`__
 documented `here <https://kivy.org/doc/stable/>`__.
 
+.. list-table::
+
+    * - .. figure:: ../_images/kivy_lisz_root.png
+           :alt: root list of a dark themed kivy lisz app
+           :scale: 30 %
+           :target: ../_images/kivy_lisz_root.png
+
+           kivy lisz app root list
+
+      - .. figure:: ../_images/kivy_lisz_fruits.png
+           :alt: fruits sub-list of a dark themed kivy lisz app
+           :scale: 30 %
+           :target: ../_images/kivy_lisz_fruits.png
+
+           fruits sub-list
+
+      - .. figure:: ../_images/kivy_lisz_fruits_light.png
+           :alt: fruits sub-list of a light themed kivy lisz app
+           :scale: 30 %
+           :target: ../_images/kivy_lisz_fruits_light.png
+
+           using light theme
+
+    * - .. figure:: ../_images/kivy_lisz_user_prefs.png
+           :alt: user preferences drop down
+           :scale: 30 %
+           :target: ../_images/kivy_lisz_user_prefs.png
+
+           lisz user preferences
+
+      - .. figure:: ../_images/kivy_lisz_color_editor.png
+           :alt: kivy lisz color editor
+           :scale: 30 %
+           :target: ../_images/kivy_lisz_color_editor.png
+
+           kivy lisz color editor
+
+      - .. figure:: ../_images/kivy_lisz_font_size_big.png
+           :alt: lisz app using bigger font size
+           :scale: 30 %
+           :target: ../_images/kivy_lisz_font_size_big.png
+
+           bigger font size
+
 
 kivy wish list
 ^^^^^^^^^^^^^^
@@ -146,6 +190,23 @@ based on the `enaml framework <https://pypi.org/project/enaml/>`__,
 a `pypi package <https://pypi.org/project/enaml/>`__
 documented `here at ReadTheDocs <https://enaml.readthedocs.io/en/latest/>`__.
 
+.. list-table::
+    :widths: 27 66
+
+    * - .. figure:: ../_images/enaml_lisz_fruits_sub_list.png
+           :alt: fruits sub-list of dark themed enaml lisz app
+           :scale: 27 %
+           :target: ../_images/enaml_lisz_fruits_sub_list.png
+
+           enaml/qt lisz app
+
+      - .. figure:: ../_images/enaml_lisz_light_landscape.png
+           :alt: fruits sub-list of a light themed enaml lisz app in landscape
+           :scale: 66 %
+           :target: ../_images/enaml_lisz_light_landscape.png
+
+           light themed in landscape
+
 
 automatic update of widget attributes
 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@@ -180,13 +241,13 @@ import pathlib
 from pprint import pformat
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
-from ae.base import file_content, file_write, norm_line_sep, norm_name, os_platform         # type: ignore
+from ae.base import file_content, file_write, norm_line_sep, norm_name                      # type: ignore
 from ae.core import DEBUG_LEVEL_VERBOSE                                                     # type: ignore
 from ae.i18n import get_f_string                                                            # type: ignore
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action               # type: ignore
 
 
-__version__ = '0.1.37'
+__version__ = '0.1.39'
 
 
 FLOW_PATH_ROOT_ID = 'ROOT'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -728,11 +789,6 @@ class LiszDataMixin(ABC):
         :param folder_path: path to the folder where the node files are situated (def=current working directory).
         :return:            list of node file tuples of (node_name, node, file_path, error-message).
         """
-        if os_platform == 'android':                                                # pragma: no cover
-            # noinspection PyUnresolvedReferences
-            from android.permissions import request_permissions, Permission         # type: ignore
-            request_permissions([Permission.READ_EXTERNAL_STORAGE])
-
         node_file_info_tuples = list()
         for node_file in os.scandir(folder_path):
             file_name = node_file.name
